# InfuPy
InfuPy is a Python library to control syringe pumps.
InfuPy is currently in an early stage of development and is meant for
testing and simulation purposes only. Do not use it on real patients
under any circumstances.
